@@ -43,9 +43,9 @@ from .utils import KOSMORRO_VERSION
 
 
 class Dumper(ABC):
-    ephemerides: [AsterEphemerides]
+    ephemerides: list[AsterEphemerides]
     moon_phase: MoonPhase
-    events: [Event]
+    events: list[Event]
     date: datetime.date
     timezone: int
     with_colors: bool
@@ -53,9 +53,9 @@ class Dumper(ABC):
 
     def __init__(
         self,
-        ephemerides: [AsterEphemerides],
+        ephemerides: list[AsterEphemerides],
         moon_phase: MoonPhase,
-        events: [Event],
+        events: list[Event],
         date: datetime.date,
         timezone: int,
         with_colors: bool,
@@ -233,11 +233,8 @@ class TextDumper(Dumper):
         if moon_phase is None:
             return _("Moon phase is unavailable for this date.")
 
-        current_moon_phase = " ".join(
-            [
-                self.style(_("Moon phase:"), "strong"),
-                strings.from_moon_phase(moon_phase.phase_type),
-            ]
+        current_moon_phase = self.style(
+            strings.from_moon_phase(moon_phase.phase_type), "strong"
         )
         new_moon_phase = _(
             "{next_moon_phase} on {next_moon_phase_date} at {next_moon_phase_time}"
@@ -250,10 +247,13 @@ class TextDumper(Dumper):
         return "\n".join([current_moon_phase, new_moon_phase])
 
 
-class _LatexDumper(Dumper):
+class LatexDumper(Dumper):
     def to_string(self):
         template_path = os.path.join(
-            os.path.abspath(os.path.dirname(__file__)), "assets", "pdf", "template.tex"
+            os.path.abspath(os.path.dirname(__file__)),
+            "assets",
+            "latex",
+            "template.tex",
         )
 
         with open(template_path, mode="r") as file:
@@ -281,7 +281,7 @@ class _LatexDumper(Dumper):
 
         document = template
 
-        if self.ephemerides is None:
+        if len(self.ephemerides) == 0:
             document = self._remove_section(document, "ephemerides")
 
         if len(self.events) == 0:
@@ -301,6 +301,9 @@ class _LatexDumper(Dumper):
     def add_strings(
         self, document: str, kosmorro_logo_path: str, moon_phase_graphics: str
     ) -> str:
+        document = document.replace(
+            "+++CURRENT-DATE+++", datetime.datetime.now().isoformat()
+        )
         document = document.replace("+++KOSMORRO-VERSION+++", KOSMORRO_VERSION)
         document = document.replace("+++KOSMORRO-LOGO+++", kosmorro_logo_path)
         document = document.replace("+++DOCUMENT-TITLE+++", _("Overview of your sky"))
@@ -317,9 +320,9 @@ class _LatexDumper(Dumper):
                         "All the hours are given in {timezone}."
                     ).format(
                         date=self.get_date_as_string(),
-                        timezone="UTC+%d" % self.timezone
-                        if self.timezone != 0
-                        else "UTC",
+                        timezone=(
+                            "UTC+%d" % self.timezone if self.timezone != 0 else "UTC"
+                        ),
                     ),
                     _(
                         "Don't forget to check the weather forecast before you go out with your equipment."
@@ -471,7 +474,7 @@ class _LatexDumper(Dumper):
 class PdfDumper(Dumper):
     def to_string(self):
         try:
-            latex_dumper = _LatexDumper(
+            latex_dumper = LatexDumper(
                 self.ephemerides,
                 self.moon_phase,
                 self.events,
@@ -497,7 +500,6 @@ class PdfDumper(Dumper):
 
     @staticmethod
     def _compile(latex_input) -> bytes:
-        package = str(Path(__file__).parent.absolute()) + "/assets/pdf/kosmorro.sty"
         timestamp = datetime.datetime.now().strftime("%Y%m%d%H%M%S")
         current_dir = (
             os.getcwd()
@@ -505,9 +507,6 @@ class PdfDumper(Dumper):
 
         try:
             temp_dir = tempfile.mkdtemp()
-
-            shutil.copy(package, temp_dir)
-
             temp_tex = "%s/%s.tex" % (temp_dir, timestamp)
 
             with open(temp_tex, "w") as tex_file:
